"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProductRecord = void 0;
const error_1 = require("../utils/error");
const uuid_1 = require("uuid");
const db_1 = require("../utils/db");
class ProductRecord {
    constructor(obj) {
        var _a;
        if (!obj.name || obj.name.length > 100) {
            throw new error_1.ValidationError('The name cannot be empty and the length cannot has more than 100 characters!');
        }
        if (!obj.price) {
            throw new error_1.ValidationError('Price is required!');
        }
        this.id = obj.id;
        this.name = obj.name;
        this.price = obj.price;
        this.updateDate = (_a = obj.updateDate) !== null && _a !== void 0 ? _a : null;
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute("INSERT INTO `products` VALUES (:id, :name, :price, :updateDate)", {
                id: this.id,
                name: this.name,
                price: this.price,
                updateDate: this.updateDate,
            });
            return this;
        });
    }
    ;
    static getAllProducts() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `products`");
            return results.map(product => new ProductRecord(product));
        });
    }
    static getOneProductDetails(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `products` WHERE `id` = :id", {
                id,
            });
            return results.length === 0 ? null : new ProductRecord(results[0]);
        });
    }
    static updateOneProduct(obj) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!obj.id) {
                throw new error_1.ValidationError('Product id is required!');
            }
            yield db_1.pool.execute("UPDATE `products` SET `name` = :name, `price` = :price, `updateDate` = :updateDate WHERE `products`.`id` = :id", {
                name: obj.name,
                price: obj.price,
                updateDate: new Date(),
                id: obj.id,
            });
        });
    }
    static deleteOneProduct(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `products` WHERE `id` = :id", {
                id,
            });
        });
    }
}
exports.ProductRecord = ProductRecord;
//# sourceMappingURL=product.record.js.map